Module blaxel.core.client.models.job_execution
==============================================

Classes
-------

`JobExecution(metadata: blaxel.core.client.types.Unset | ForwardRef('JobExecutionMetadata') = <blaxel.core.client.types.Unset object>, spec: blaxel.core.client.types.Unset | ForwardRef('JobExecutionSpec') = <blaxel.core.client.types.Unset object>, stats: blaxel.core.client.types.Unset | ForwardRef('JobExecutionStats') = <blaxel.core.client.types.Unset object>, status: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, tasks: blaxel.core.client.types.Unset | list['JobExecutionTask'] = <blaxel.core.client.types.Unset object>)`
:   Job execution
    
    Attributes:
        metadata (Union[Unset, JobExecutionMetadata]): Job execution metadata
        spec (Union[Unset, JobExecutionSpec]): Job execution specification
        stats (Union[Unset, JobExecutionStats]): Job execution statistics
        status (Union[Unset, str]): Job execution status
        tasks (Union[Unset, list['JobExecutionTask']]): List of execution tasks
    
    Method generated by attrs for class JobExecution.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `metadata`
    :

    `spec`
    :

    `stats`
    :

    `status`
    :

    `tasks`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :